export const on = (function() {
    if (document.addEventListener) {
        return function(element, event, handler) {
            if (element && event && handler) {
                element.addEventListener(event, handler, false)
            }
        }
    } else {
        return function(element, event, handler) {
            if (element && event && handler) {
                element.attachEvent('on' + event, handler)
            }
        }
    }
})()

export const off = (function() {
    if (document.removeEventListener) {
        return function(element, event, handler) {
            if (element && event) {
                element.removeEventListener(event, handler, false)
            }
        }
    } else {
        return function(element, event, handler) {
            if (element && event) {
                element.detachEvent('on' + event, handler)
            }
        }
    }
})()

/**
 * @description: 加载远程js文件
 * @param {String} url 远程地址
 * @param {Function} callback 加载成功的回调函数
 * @param {Function} errorCallback 加载失败的回调函数
 * @return: 
 */
export const loadScript = (url = '', callback = '', errorCallback = '') => {
    if(url){
        let script = document.createElement("script")
        script.type = "text/javascript"
        script.src = url
        // script.async = true
        script.onload = function() {
            callback && callback()
        }
        script.onerror = function(){
            errorCallback && errorCallback()
        }
        window.document.body.appendChild(script)
    }
}
